RevenueCat

pub package

purchases_flutter

purchases_flutter is a client for the RevenueCat subscription and purchase tracking system. It is an open source framework that provides a wrapper around StoreKit, Google Play Billing and the RevenueCat backend to make implementing in-app subscriptions in Flutter easy - receipt validation and status tracking included!

Features

RevenueCat
Server-side receipt validation
➡️ Webhooks - enhanced server-to-server communication with events for purchases, renewals, cancellations, and more
🎯 Subscription status tracking - know whether a user is subscribed whether they're on iOS or Android
📊 Analytics - automatic calculation of metrics like conversion, mrr, and churn
📝 Online documentation and SDK Reference up to date
🔀 Integrations - over a dozen integrations to easily send purchase data where you need it
💯 Well maintained - frequent releases
📮 Great support - Help Center

Installation

To use this plugin, add purchases_flutter as a dependency in your pubspec.yaml file.

Requirements

purchases_flutter requires Xcode 14.0+ and minimum targets iOS 13.0+/Android SDK 21+ (Android 5.0+).

SDK Reference

Our full SDK reference can be found here.

Getting Started

For more detailed information, you can view our complete documentation at docs.revenuecat.com.

Libraries

errors
models/ad_displayed_data
models/ad_failed_to_load_data
models/ad_format
models/ad_loaded_data
models/ad_mediator_name
models/ad_opened_data
models/ad_revenue_data
models/ad_revenue_precision
models/custom_paywall_impression_params
models/customer_info_wrapper
models/entitlement_info_wrapper
models/entitlement_infos_wrapper
models/entitlement_verification_mode
models/google_product_change
models/installments_info
models/introductory_price
models/map_helpers
models/offering_wrapper
models/offerings_wrapper
models/package_wrapper
models/period_unit
models/period_wrapper
models/presented_offering_context_wrapper
models/presented_offering_targeting_context_wrapper
models/price_wrapper
models/pricing_phase_wrapper
models/product_category
models/promotional_offer
models/purchase_params
models/purchase_result
models/purchases_completed_by
models/purchases_configuration
models/purchases_error
models/reward_verification_result
models/reward_verification_token
models/rewarded_ad_tracking_metadata
models/store
models/store_product_change
models/store_product_discount
models/store_product_wrapper
models/store_transaction
models/storefront
models/storekit_version
models/subscription_info_wrapper
models/subscription_option_wrapper
models/upgrade_info
models/verification_result
models/verified_reward
models/virtual_currencies
models/virtual_currency
models/web_purchase_redemption
models/web_purchase_redemption_result
models/win_back_offer
object_wrappers
purchases_flutter
web/purchases_flutter_web