AdFailedToLoadData class

Annotations
  • @experimental

Constructors

AdFailedToLoadData({required AdMediatorName mediatorName, required AdFormat adFormat, String? placement, required String adUnitId, int? mediatorErrorCode})
const

Properties

adFormat AdFormat
final
adUnitId String
final
hashCode int
The hash code for this object.
no setterinherited
mediatorErrorCode int?
final
mediatorName AdMediatorName
final
placement String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited