AdFormat class

Use the predefined constants for common ad formats, or create a custom value for other ad format types.

Annotations
  • @experimental

Constructors

AdFormat(String value)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

appOpen → const AdFormat
interstitial → const AdFormat
nativeAd → const AdFormat
other → const AdFormat
rewarded → const AdFormat
rewardedInterstitial → const AdFormat