AdMediatorName class
Use the predefined constants for common mediators, or create a custom value for other mediation networks.
- Annotations
-
- @experimental
Constructors
- AdMediatorName(String value)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- adMob → const AdMediatorName
- appLovin → const AdMediatorName