AdRevenueData class

Annotations
  • @experimental

Constructors

AdRevenueData({String? networkName, required AdMediatorName mediatorName, required AdFormat adFormat, String? placement, required String adUnitId, required String impressionId, required int revenueMicros, required String currency, required AdRevenuePrecision precision})
const

Properties

adFormat AdFormat
final
adUnitId String
final
currency String
final
hashCode int
The hash code for this object.
no setterinherited
impressionId String
final
mediatorName AdMediatorName
final
networkName String?
final
placement String?
final
precision AdRevenuePrecision
final
revenueMicros int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited