AdRevenuePrecision class

Use the predefined constants for common precision types, or create a custom value for other precision types.

Annotations
  • @experimental

Constructors

AdRevenuePrecision(String value)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override