EntitlementInfos class

This class contains all the entitlements associated to the user.

Constructors

EntitlementInfos(Map<String, EntitlementInfo> all, Map<String, EntitlementInfo> active, {VerificationResult verification = VerificationResult.notRequested})
const
EntitlementInfos.fromJson(Map<String, dynamic> json)
factory

Properties

active → Map<String, EntitlementInfo>
Map of active EntitlementInfo (EntitlementInfo) objects keyed by entitlement identifier.
final
all → Map<String, EntitlementInfo>
Map of all EntitlementInfo (EntitlementInfo) objects (active and inactive) keyed by entitlement identifier.
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
verification → VerificationResult
If entitlement verification was enabled, the result of that verification. If not, VerificationResult.NOT_REQUESTED.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited