GoogleProductChangeInfo class

Annotations

Constructors

GoogleProductChangeInfo(String oldProductIdentifier, {GoogleProrationMode? prorationMode})
Constructs an GoogleProductChangeInfo

Properties

hashCode → int
The hash code for this object.
no setterinherited
oldProductIdentifier ↔ String
The oldProductIdentifier to change from.
getter/setter pair
prorationMode ↔ GoogleProrationMode?
The GoogleProrationMode to use when changing from the given oldProductIdentifer. Defaults to GoogleProrationMode.immediateWithoutProration
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited