InstallmentsInfo class

Type containing information of installment subscriptions. Currently only supported in Google Play.

Constructors

InstallmentsInfo(int commitmentPaymentsCount, int renewalCommitmentPaymentsCount)
const
InstallmentsInfo.fromJson(Map<String, dynamic> json)
factory

Properties

commitmentPaymentsCount → int
Number of payments the customer commits to in order to purchase the subscription.
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
renewalCommitmentPaymentsCount → int
After the commitment payments are complete, the number of payments the user commits to upon a renewal.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited