IntroductoryPrice class

Constructors

IntroductoryPrice(double price, String priceString, String period, int cycles, PeriodUnit periodUnit, int periodNumberOfUnits)
const
IntroductoryPrice.fromJson(Map<String, dynamic> json)
factory

Properties

cycles → int
Number of subscription billing periods for which the user will be given the introductory price, such as 3.
final
hashCode → int
The hash code for this object.
no setterinherited
period → String
Billing period of the introductory price, specified in ISO 8601 format.
final
periodNumberOfUnits → int
Number of units for the billing period of the introductory price.
final
periodUnit → PeriodUnit
Unit for the billing period of the introductory price, can be DAY, WEEK, MONTH or YEAR.
final
price → double
Introductory price of a subscription in the local currency.
final
priceString → String
Formatted introductory price of a subscription, including its currency sign, such as €3.99.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited