Offerings class

This class contains all the offerings configured in RevenueCat dashboard. For more info see https://docs.revenuecat.com/docs/entitlements

Constructors

Offerings(Map<String, Offering> all, {Offering? current})
const
Offerings.fromJson(Map<String, dynamic> json)
factory

Properties

all → Map<String, Offering>
Map of all Offerings Offering objects keyed by their identifier.
final
current → Offering?
Current offering configured in the RevenueCat dashboard.
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

getOffering(String identifier) → Offering?
Retrieves a specific offering by its identifier.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited