Price class

Contains all the details associated with a Price

Constructors

Price(String formatted, int amountMicros, String currencyCode)
const
Price.fromJson(Map<String, dynamic> json)
factory

Properties

amountMicros → int
Price in micro-units, where 1,000,000 micro-units equal one unit of the currency.
final
currencyCode → String
Returns ISO 4217 currency code for price and original price.
final
formatted → String
Formatted price of the item, including its currency sign. For example $3.00
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited