PurchaseParams class

Parameters for making a purchase.

Constructors

PurchaseParams.package(Package package, {StoreProductChangeInfo? productChangeInfo, @Deprecated('Use productChangeInfo') GoogleProductChangeInfo? googleProductChangeInfo, bool? googleIsPersonalizedPrice, PromotionalOffer? promotionalOffer, WinBackOffer? winBackOffer, String? customerEmail})
Creates purchase parameters for a package.
const
PurchaseParams.storeProduct(StoreProduct storeProduct, {StoreProductChangeInfo? productChangeInfo, @Deprecated('Use productChangeInfo') GoogleProductChangeInfo? googleProductChangeInfo, bool? googleIsPersonalizedPrice, PromotionalOffer? promotionalOffer, WinBackOffer? winBackOffer, String? customerEmail})
Creates purchase parameters for a store product.
const
PurchaseParams.subscriptionOption(SubscriptionOption subscriptionOption, {StoreProductChangeInfo? productChangeInfo, @Deprecated('Use productChangeInfo') GoogleProductChangeInfo? googleProductChangeInfo, bool? googleIsPersonalizedPrice, String? customerEmail})
Creates purchase parameters for a subscription option. Google Play-only.
const

Properties

customerEmail → String?
final
googleIsPersonalizedPrice → bool?
final
googleProductChangeInfo → GoogleProductChangeInfo?
final
hashCode → int
The hash code for this object.
no setterinherited
package → Package?
final
product → StoreProduct?
final
productChangeInfo → StoreProductChangeInfo?
final
promotionalOffer → PromotionalOffer?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionOption → SubscriptionOption?
final
winBackOffer → WinBackOffer?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited