PurchaseParams.subscriptionOption constructor

const PurchaseParams.subscriptionOption(
  1. SubscriptionOption subscriptionOption, {
  2. StoreProductChangeInfo? productChangeInfo,
  3. @Deprecated('Use productChangeInfo') GoogleProductChangeInfo? googleProductChangeInfo,
  4. bool? googleIsPersonalizedPrice,
  5. String? customerEmail,
})

Creates purchase parameters for a subscription option. Google Play-only.

subscriptionOption The subscription option to purchase.

productChangeInfo Android and store-specific only. Optional StoreProductChangeInfo you wish to change from containing the oldProductIdentifier and the optional replacementMode.

googleProductChangeInfo Android and Google Play only. Optional GoogleProductChangeInfo you wish to change from containing the googleOldProductIdentifier and the optional prorationMode.

googleIsPersonalizedPrice Android and Google Play only. Optional boolean indicates personalized pricing on products available for purchase in the EU. For compliance with EU regulations. User will see "This price has been customized for you" in the purchase dialog when true. See https://developer.android.com/google/play/billing/integrate#personalized-price for more info.

customerEmail Web only. The email of the user. If undefined, RevenueCat will ask the customer for their email.

Implementation

const PurchaseParams.subscriptionOption(
  SubscriptionOption subscriptionOption, {
  StoreProductChangeInfo? productChangeInfo,
  @Deprecated('Use productChangeInfo')
  GoogleProductChangeInfo? googleProductChangeInfo,
  bool? googleIsPersonalizedPrice,
  String? customerEmail,
}) : this._(
        null,
        null,
        subscriptionOption,
        productChangeInfo,
        googleProductChangeInfo,
        googleIsPersonalizedPrice,
        null,
        null,
        customerEmail,
      );