PurchaseResult class

Represents the successful result of a purchase operation.

Constructors

PurchaseResult(CustomerInfo customerInfo, StoreTransaction storeTransaction)
const
PurchaseResult.fromJson(Map<String, dynamic> json)
factory

Properties

customerInfo → CustomerInfo
The updated CustomerInfo after the purchase has been synced with RevenueCat's servers.
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storeTransaction → StoreTransaction
The StoreTransaction for this purchase.
final
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited