RewardVerificationResult class

Result delivered after reward verification polling for a rewarded ad.

Annotations
  • @experimental

Constructors

RewardVerificationResult({required bool failed, VerifiedReward? reward, List<VerifiedReward> moreRewards = const []})
const
RewardVerificationResult.fromMap(Map<String, dynamic> map)
factory

Properties

failed bool
True when verification did not complete successfully (rejected, timeout, network, etc.).
final
hashCode int
The hash code for this object.
no setterinherited
moreRewards List<VerifiedReward>
The remaining granted rewards. Empty for a single reward or on failure.
final
reward VerifiedReward?
The first granted reward, or null when verification failed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited