StoreProductChangeInfo class

Store-specific replacement information for changing products.

Constructors

StoreProductChangeInfo(String oldProductIdentifier, {StoreReplacementMode? replacementMode})
Constructs a StoreProductChangeInfo.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
oldProductIdentifier → String
The old product identifier to change from.
final
replacementMode → StoreReplacementMode?
The replacement mode to use when changing from the old product.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited