replacementMode property
The replacement mode to use when changing from the old product.
Defaults to store-specific behavior when not provided.
Implementation
final StoreReplacementMode? replacementMode;
The replacement mode to use when changing from the old product.
Defaults to store-specific behavior when not provided.
final StoreReplacementMode? replacementMode;