StoreReplacementMode enum

Replacement modes for product changes.

Inheritance
Available extensions

Values

withTimeProration → const StoreReplacementMode

Replacement takes effect immediately, and the remaining time will be prorated and credited to the user.

chargeProratedPrice → const StoreReplacementMode

Replacement takes effect immediately, and the user is charged a prorated price for the new product for the remainder of the billing cycle.

withoutProration → const StoreReplacementMode

Replacement takes effect immediately, and the new price will be charged on next recurrence time. The billing cycle stays the same.

chargeFullPrice → const StoreReplacementMode

Replacement takes effect immediately, and the user is charged full price of the new product and given a full billing cycle.

deferred → const StoreReplacementMode

Replacement takes effect when the old product expires, and the new price will be charged at the same time.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String

Available on StoreReplacementMode, provided by the StoreReplacementModeExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StoreReplacementMode>
A constant List of the values in this enum, in order of their declaration.