StoreProduct class

Available extensions

Constructors

StoreProduct(String identifier, String description, String title, double price, String priceString, String currencyCode, {IntroductoryPrice? introductoryPrice, List<StoreProductDiscount>? discounts, ProductCategory? productCategory, SubscriptionOption? defaultOption, List<SubscriptionOption>? subscriptionOptions, PresentedOfferingContext? presentedOfferingContext, String? subscriptionPeriod, double? pricePerWeek, double? pricePerMonth, double? pricePerYear, String? pricePerWeekString, String? pricePerMonthString, String? pricePerYearString})
const
StoreProduct.fromJson(Map<String, dynamic> json)
factory

Properties

currencyCode → String
Currency code for price and original price.
final
defaultOption → SubscriptionOption?
Default subscription option for a product. Google Play only.
final
description → String
Description of the product.
final
discounts → List<StoreProductDiscount>?
Collection of discount offers for a product. Null for Android.
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → String
Product Id.
final
introductoryPrice → IntroductoryPrice?
Introductory price for product. Can be null.
final
presentedOfferingContext → PresentedOfferingContext?
Offering context this package belongs to. Null if not using offerings or if fetched directly from store via getProducts
final
presentedOfferingIdentifier → String?

Available on StoreProduct, provided by the ExtendedStoreProduct extension

Offering this package belongs to. Null if not using offerings or if fetched directly from store via getProducts
no setter
price → double
Price of the product in the local currency.
final
pricePerMonth → double?
Price per month in the local currency. Null for non-subscription products.
final
pricePerMonthString → String?
Formatted price per month, including its currency sign. Null for non-subscription products.
final
pricePerWeek → double?
Price per week in the local currency. Null for non-subscription products.
final
pricePerWeekString → String?
Formatted price per week, including its currency sign. Null for non-subscription products.
final
pricePerYear → double?
Price per year in the local currency. Null for non-subscription products.
final
pricePerYearString → String?
Formatted price per year, including its currency sign. Null for non-subscription products.
final
priceString → String
Formatted price of the item, including its currency sign.
final
productCategory → ProductCategory?
Product category.
final
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
subscriptionOptions → List<SubscriptionOption>?
Collection of subscription options for a product. Google Play only.
final
subscriptionPeriod → String?
Subscription period, specified in ISO 8601 format. For example, P1W equates to one week, P1M equates to one month, P3M equates to three months, P6M equates to six months, and P1Y equates to one year. Note: Not available for Amazon.
final
title → String
Title of the product.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited