SubscriptionInfo class

Subscription purchase of a customer, keyed by product identifier in CustomerInfo.subscriptionsByProductIdentifier.

Constructors

SubscriptionInfo(String productIdentifier, String purchaseDate, bool isSandbox, bool isActive, bool willRenew, {String? originalPurchaseDate, String? expiresDate, Store store = Store.unknownStore, String? unsubscribeDetectedAt, String? billingIssuesDetectedAt, String? gracePeriodExpiresDate, OwnershipType ownershipType = OwnershipType.unknown, PeriodType periodType = PeriodType.unknown, String? refundedAt, String? storeTransactionId, String? autoResumeDate, String? displayName, String? managementURL, String? productPlanIdentifier})
const
SubscriptionInfo.fromJson(Map<String, dynamic> json)
factory

Properties

autoResumeDate String?
The date the paused subscription will automatically resume. Only set for Google Play subscriptions that have been paused; null otherwise.
final
billingIssuesDetectedAt String?
Date when RevenueCat detected any billing issues with this subscription. If and when the billing issue gets resolved, this field is set to null. Note the subscription may still be active, check the expiresDate attribute.
final
displayName String?
The display name of the subscription as configured in the RevenueCat dashboard.
final
expiresDate String?
Date when the subscription expires/expired. Can be null for non-subscriptions.
final
gracePeriodExpiresDate String?
Date when any grace period for this subscription expires/expired. Null if the customer has never been in a grace period.
final
hashCode int
The hash code for this object.
no setterinherited
isActive bool
Whether the subscription is currently active.
final
isSandbox bool
Whether or not the purchase was made in sandbox mode.
final
managementURL String?
The URL to manage this subscription in the store. Can be null.
final
originalPurchaseDate String?
Date when this subscription first started. Can be null for non-subscriptions.
final
ownershipType OwnershipType
How the customer received access to this subscription.
final
periodType PeriodType
Type of the current subscription period.
final
productIdentifier String
The product identifier.
final
productPlanIdentifier String?
The base plan identifier that unlocked this subscription (Google Play base plans and Apple purchases with non-upfront billing plans). Null otherwise.
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
purchaseDate String
Date when the last subscription period started.
final
refundedAt String?
Date when RevenueCat detected a refund of this subscription.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
store Store
Store where the subscription was purchased.
final
storeTransactionId String?
The transaction id in the store of the subscription.
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
unsubscribeDetectedAt String?
Date when RevenueCat detected that auto-renewal was turned off for this subscription. Note the subscription may still be active, check the expiresDate attribute.
final
willRenew bool
Whether the subscription will renew at the next billing period.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited