autoResumeDate property
The date the paused subscription will automatically resume. Only set for Google Play subscriptions that have been paused; null otherwise.
Implementation
final String? autoResumeDate;
The date the paused subscription will automatically resume. Only set for Google Play subscriptions that have been paused; null otherwise.
final String? autoResumeDate;