displayName property
The display name of the subscription as configured in the RevenueCat dashboard.
Implementation
final String? displayName;
The display name of the subscription as configured in the RevenueCat dashboard.
final String? displayName;