productPlanIdentifier property

String? productPlanIdentifier
final

The base plan identifier that unlocked this subscription (Google Play base plans and Apple purchases with non-upfront billing plans). Null otherwise.

Implementation

final String? productPlanIdentifier;