unsubscribeDetectedAt property
Date when RevenueCat detected that auto-renewal was turned off for this subscription. Note the subscription may still be active, check the expiresDate attribute.
Implementation
final String? unsubscribeDetectedAt;
Date when RevenueCat detected that auto-renewal was turned off for this subscription. Note the subscription may still be active, check the expiresDate attribute.
final String? unsubscribeDetectedAt;