models/verified_reward library
Classes
- VerifiedEntitlementReward
- A reward granting the entitlement identifier.
- VerifiedNoReward
- Verification completed but no reward was granted.
- VerifiedReward
- A single reward granted by a verified rewarded ad.
- VerifiedUnsupportedReward
- Verification completed with a reward type not modeled by this SDK version.
- VerifiedVirtualCurrencyReward
- A reward of amount units of the virtual currency code.