VerifiedEntitlementReward class

A reward granting the entitlement identifier.

Inheritance
Annotations
  • @experimental

Constructors

VerifiedEntitlementReward({required String identifier, DateTime? expiresAt})
const

Properties

expiresAt DateTime?
When the entitlement expires, or null if it does not expire.
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited