AdFormat class
Use the predefined constants for common ad formats, or create a custom value for other ad format types.
- Annotations
-
- @experimental
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override