AdRevenuePrecision class
Use the predefined constants for common precision types, or create a custom value for other precision types.
- Annotations
-
- @experimental
Constructors
- AdRevenuePrecision(String value)
-
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override
Constants
- estimated → const AdRevenuePrecision
- exact → const AdRevenuePrecision
- publisherDefined → const AdRevenuePrecision
- unknown → const AdRevenuePrecision