CustomPaywallImpressionParams class

Parameters for tracking a custom paywall impression.

Use this class to provide additional context when tracking custom paywall impressions with Purchases.trackCustomPaywallImpression.

Constructors

CustomPaywallImpressionParams({String? paywallId, String? offeringId})
Creates CustomPaywallImpressionParams with an optional paywallId and offeringId.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
offeringId String?
An optional identifier for the offering associated with the custom paywall. If not provided, the SDK will use the current offering identifier from the cache.
final
paywallId String?
An optional identifier for the paywall being displayed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited