offeringId property
An optional identifier for the offering associated with the custom paywall. If not provided, the SDK will use the current offering identifier from the cache.
Implementation
final String? offeringId;
An optional identifier for the offering associated with the custom paywall. If not provided, the SDK will use the current offering identifier from the cache.
final String? offeringId;