RewardVerificationToken class
Ties a loaded rewarded ad to its server-side reward verification.
Produced by Purchases.generateRewardVerificationToken. Forward customData and appUserID to your ad network's server-side verification options, and keep clientTransactionId to correlate the reward callback with Purchases.pollRewardVerification.
- Annotations
-
- @experimental
Constructors
- RewardVerificationToken({required String customData, required String clientTransactionId, required String appUserID})
-
const
-
RewardVerificationToken.fromMap(Map<
String, dynamic> map) -
factory
Properties
- appUserID → String
-
final
- clientTransactionId → String
-
final
- customData → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited