VerifiedReward class abstract
A single reward granted by a verified rewarded ad.
This is an abstract base type; inspect the concrete subtype to read the reward's data: VerifiedVirtualCurrencyReward, VerifiedEntitlementReward, VerifiedNoReward, or VerifiedUnsupportedReward.
final reward = result.reward;
if (reward is VerifiedVirtualCurrencyReward) {
grantCurrency(reward.code, reward.amount);
} else if (reward is VerifiedEntitlementReward) {
unlock(reward.identifier);
}
- Implementers
- Annotations
-
- @experimental
Constructors
-
VerifiedReward.fromMap(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited